@@ -24,8 +24,14 @@ class MetricsBuffer(object):
         self.processing_queue = queue.Queue(self._processing_queue_size)
         self.pending_queue = queue.Queue(max_requests_to_buffer)
 
-        collectd.info('Initialized MetricsBuffer with max_requests_to_buffer %s' %
-                      max_requests_to_buffer)
+        # metrics
+        self.dropped_batch_count = 0
+        self.dropped_metric_count = 0
+
+        collectd.info(
+            "Initialized MetricsBuffer with max_requests_to_buffer %s"
+            % max_requests_to_buffer
+        )
 
     def get_batch(self):
         """
@@ -49,8 +55,10 @@ class MetricsBuffer(object):
 
         if self.pending_queue.full():
             batch_to_drop = self.pending_queue.get()
-            self.collectd.warning('In memory buffer is full, dropping metrics batch %s'
-                                  % batch_to_drop)
+            self.collectd.warning(
+                "In memory buffer is full, dropping metrics batch %s" % batch_to_drop
+            )
+            self._drop_batch(batch_to_drop)
 
         self.pending_queue.put(batch)
 
@@ -60,12 +68,29 @@ class MetricsBuffer(object):
         """
 
         if self.pending_queue.full():
-            self.collectd.warning('Sending metrics batch %s failed. '
-                                  'In memory buffer is full, dropping metrics batch' % batch)
+            self.collectd.warning(
+                "Sending metrics batch %s failed. "
+                "In memory buffer is full, dropping metrics batch" % batch
+            )
+            self._drop_batch(batch)
         else:
-            self.collectd.warning('Sending metrics batch %s failed. '
-                                  'Put it back to processing queue' % batch)
+            self.collectd.warning(
+                "Sending metrics batch %s failed. "
+                "Put it back to processing queue" % batch
+            )
             self.processing_queue.put(batch)
 
+    def _drop_batch(self, batch):
+        """
+        Drop the supplied batch. This will typically happen due to one of the queues being full.
+
+        This function doesn't do anything other than updating some stats.
+        """
+        self.dropped_batch_count += 1
+        self.dropped_metric_count += len(batch)
+
     def empty(self):
         return self.processing_queue.empty() and self.pending_queue.empty()
+
+    def size(self):
+        return self.processing_queue.qsize() + self.pending_queue.qsize()
